@@ -1,5 +1,6 @@
 #include <Rcpp.h>
 #include <math.h>
+#include <float.h>
 using namespace Rcpp;
 
 double univar_rgig_newapproach1 (double lambda, double lambda_old, double omega, double alpha){
@@ -113,7 +114,7 @@ double do_rgig1(double lambda,
                 double psi) {
 
   if (chi == 0){
-    chi = DOUBLE_XMIN;
+    chi = DBL_MIN;
   }
 
   if ( !(R_FINITE(lambda) && R_FINITE(chi) && R_FINITE(psi)) ||
@@ -126,7 +127,7 @@ double do_rgig1(double lambda,
   double res;
 
   // circumvent GIGrvg in these cases
-  if ((chi < (11 * DOUBLE_EPS)) & (lambda != 0)) {
+  if ((chi < (11 * DBL_EPSILON)) & (lambda != 0)) {
     /* special cases which are basically Gamma and Inverse Gamma distribution */
     if (lambda > 0.0) {
       res = R::rgamma(lambda, 2.0/psi);
@@ -136,7 +137,7 @@ double do_rgig1(double lambda,
     }
   }
 
-  else if ((psi < (11 * DOUBLE_EPS)) & (lambda != 0)) {
+  else if ((psi < (11 * DBL_EPSILON)) & (lambda != 0)) {
     /* special cases which are basically Gamma and Inverse Gamma distribution */
     if (lambda > 0.0) {
       res = R::rgamma(lambda, 2.0/psi);  // fixed
